@@ -1,8 +1,13 @@
+
+
 # def Conductance(r):
 #     # Look at functions as objects
 #     # https://medium.com/python-pandemonium/function-as-objects-in-python-d5215e6d1b0d
 #     return 1/r
 
+def __call__(r): #conductance
+    return 1/r 
+
 def ConductanceInSeries(g_list):
     sumOfInverse = sum([1/g for g in g_list])
     return 1/sumOfInverse
